[**Расширенные параметры**](./introduction.md) > **Код языка** _(текущая)_

---

#### Google

Источник <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, организовано GPT-4o.

| Метка на русском | Метка | `Language Code` |
| --- | --- | --- |
| Амхарский | Amharic | `am` |
| Арабский | Arabic | `ar` |
| Баскский | Basque | `eu` |
| Бенгальский | Bengali | `bn` |
| Английский (Великобритания) | English (UK) | `en-GB` |
| Португальский (Бразилия) | Portuguese (Brazil) | `pt-BR` |
| Болгарский | Bulgarian | `bg` |
| Каталанский | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Хорватский | Croatian | `hr` |
| Чешский | Czech | `cs` |
| Датский | Danish | `da` |
| Голландский | Dutch | `nl` |
| Английский (США) | English (US) | `en` |
| 爱沙尼亚语 | Estonian | `et` |
| Филиппинский | Filipino | `fil` |
| Финский | Finnish | `fi` |
| Французский | French | `fr` |
| Немецкий | German | `de` |
| Греческий | Greek | `el` |
| Гуджарати | Gujarati | `gu` |
| Иврит | Hebrew | `iw` |
| Хинди | Hindi | `hi` |
| Венгерский | Hungarian | `hu` |
| 冰岛语 | Icelandic | `is` |
|  Индонезийский | Indonesian | `id` |
| Итальянский | Italian | `it` |
| Японский | Japanese | `ja` |
| Каннада | Kannada | `kn` |
| 韩语 | Korean | `ko` |
| Латвийский | Latvian | `lv` |
| Литовский | Lithuanian | `lt` |
| Малайский | Malay | `ms` |
| Малаялам | Malayalam | `ml` |
| 马拉地语 | Marathi | `mr` |
| Норвежский | Norwegian | `no` |
| Польский | Polish | `pl` |
| Португальский (Португалия) | Portuguese (Portugal) | `pt-PT` |
| Румынский | Romanian | `ro` |
| Русский | Russian | `ru` |
| 塞尔维亚语 | Serbian | `sr` |
| Русский (Россия) | Russian (Russia) | `ru-RU` |
| Словацкий | Slovak | `sk` |
| Словенский | Slovenian | `sl` |
| Испанский | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| Шведский | Swedish | `sv` |
| Тамильский | Tamil | `ta` |
| телугу | Telugu | `te` |
| 泰语 | Thai | `th` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| 土耳其语 | Turkish | `tr` |
| Урду | Urdu | `ur` |
| Українська | Ukrainian | `uk` |
| Вьетнамский | Vietnamese | `vi` |
| Валлийский | Welsh | `cy` |

#### DeepL

Источник <https://developers.deepl.com/docs/resources/supported-languages>, организовано GPT-4o.

| Метка на китайском | Метка | `Language Code` | Поддерживается |
| --- | --- | --- | --- |
| Арабский | Arabic | `AR` | `source`, `target` |
| Болгарский | Bulgarian | `BG` | `source`, `target` |
| Чешский | Czech | `CS` | `source`, `target` |
|  Датский | Danish | `DA` | `source`, `target` |
| 德语 | German | `DE` | `source`, `target` |
|  Греческий | Greek | `EL` | `source`, `target` |
| 俄语 | Russian | `RU` | `source`, `target` |
| 俄语 (Русский) | Russian | `RU` | `target` |
| Английский (США) | English (American) | `EN-US` | `target` |
| Испанский | Spanish | `ES` | `source`, `target` |
| Эстонский | Estonian | `ET` | `source`, `target` |
| Финский | Finnish | `FI` | `source`, `target` |
| Французский | French | `FR` | `source`, `target` |
| Венгерский | Hungarian | `HU` | `source`, `target` |
| Индонезийский | Indonesian | `ID` | `source`, `target` |
| Итальянский | Italian | `IT` | `source`, `target` |
| Японский | Japanese | `JA` | `source`, `target` |
| 韩语 | Korean | `KO` | `source`, `target` |
| Литовский | Lithuanian | `LT` | `source`, `target` |
| Латышский | Latvian | `LV` | `source`, `target` |
| Норвежский букмол | Norwegian Bokmål | `NB` | `source`, `target` |
| Голландский | Dutch | `NL` | `source`, `target` |
| Польский | Polish | `PL` | `source`, `target` |
| Португальский | Portuguese | `PT` | `source`, `target` |
| Португальский (Бразилия) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Португальский (Европа) | Portuguese (European) | `PT-PT` | `target` |
| Румынский | Romanian | `RO` | `source`, `target` |
| Русский | Russian | `RU` | `source`, `target` |
| Словацкий | Slovak | `SK` | `source`, `target` |
| Словенский | Slovenian | `SL` | `source`, `target` |
| Шведский | Swedish | `SV` | `source`, `target` |
| Турецкий | Turkish | `TR` | `source`, `target` |
| Украинский | Ukrainian | `UK` | `source`, `target` |
| 中文 | Китайский | `ZH` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>